@@ -60,15 +60,15 @@
 ## @example
 ## [z, p, k] = sos2zp ([1 0 1, 1 0 -0.81; 1 0 0, 1 0 0.49])
 ##   @result{} z =
-##     -0 + 1i
+##      0 + 1i
 ##      0 - 1i
 ##      0 + 0i
 ##      0 + 0i
 ##   @result{} p =
-##     -0.90000 + 0.00000i
-##      0.90000 + 0.00000i
-##     -0.00000 + 0.70000i
-##      0.00000 - 0.70000i
+##     -0.9000 + 0i
+##      0.9000 + 0i
+##      0 + 0.7000i
+##      0 - 0.7000i
 ##   @result{} k =  1
 ## @end example
 ##
